==> tecfy_core_package-0.1.65.tar.gz: lib/models/notification.model.dart <==
part of tecfy_core_client_package;

class UserNotification {
  String ownerId;
  String id;
  String message;
  String userName;
  String userPhotoUrl;
  String userId;

  /// FriendRequest, FriendConfirm
  String type;

  DateTime time;
  bool isSeen;
  bool isDeleted;
  bool isRequest;
  UserNotification(this.ownerId,
      {this.message,
      this.time,
      this.userName,
      this.userPhotoUrl,
      this.isSeen,
      this.isDeleted,
      this.isRequest,
      this.id,
      this.type,
      this.userId});

  UserNotification.fromJson(String id, Map<String, dynamic> data) {
    ownerId = LocalConfigService.user.id.toString();
    this.id = id;
    userName = data['name'];
    message = data['message'];
    // time = (data['createdTime'] is Timestamp)
    //     ? (data['createdTime'] as Timestamp).toDate()
    //     : data['createdTime'];
    userPhotoUrl = data['imageUrl'];
    isSeen = data['isSeen'] ?? false;
    isDeleted = data['isDeleted'] ?? false;
    isRequest = data['isRequest'] ?? false;
    userId = data['userId'];
    type = data['type'];
  }

  Map<String, dynamic> toJson() {
    return {
      'name': userName,
      'message': message,
      'createdTime': DateTime.now().toUtc(),
      'imageUrl': userPhotoUrl,
      'isSeen': false,
      'isDeleted': false,
      'isRequest': isRequest,
      'type': type,
      'userId': userId
    };
  }

  String get createdSince {
    try {
      if (time == null) return 'just now';

      var differance = DateTime.now().toUtc().difference(time);
      var years = (differance.inDays ~/ 365).toInt();
      if (years > 1) return '$years years ago';

      var months = (differance.inDays ~/ 30).toInt();
      if (months > 1) return '$months months ago';

      var weeks = (differance.inDays ~/ 7).toInt();
      if (weeks > 1) return '$weeks weeks ago';

      var days = (differance.inDays).toInt();
      if (days > 1) return '$days days ago';

      var hours = (differance.inHours).toInt();
      if (hours > 1) return '$hours hours ago';

      var minutes = (differance.inMinutes).toInt();
      if (minutes > 1) return '$minutes minutes ago';
    } catch (err) {}
    return 'Just now';
  }
}

==> tecfy_core_package-1.1.5.tar.gz: lib/models/notification.model.dart <==
part of tecfy_core_client_package;

class UserNotification {
  late String ownerId;
  late String id;
  late String message;
  late String userName;
  String? userPhotoUrl;
  late String userId;

  /// FriendRequest, FriendConfirm
  late String type;

  DateTime? time;
  bool isSeen = false;
  bool isDeleted = false;
  bool isRequest = false;
  UserNotification(this.ownerId,
      {required this.message,
      required this.time,
      required this.userName,
      this.userPhotoUrl,
      this.isSeen = false,
      this.isDeleted = false,
      this.isRequest = false,
      required this.id,
      required this.type,
      required this.userId});

  UserNotification.fromJson(String id, Map<String, dynamic> data) {
    ownerId = LocalConfigService.user!.id.toString();
    this.id = id;
    userName = data['name'];
    message = data['message'];
    // time = (data['createdTime'] is Timestamp)
    //     ? (data['createdTime'] as Timestamp).toDate()
    //     : data['createdTime'];
    userPhotoUrl = data['imageUrl'];
    isSeen = data['isSeen'] ?? false;
    isDeleted = data['isDeleted'] ?? false;
    isRequest = data['isRequest'] ?? false;
    userId = data['userId'];
    type = data['type'];
  }

  Map<String, dynamic> toJson() {
    return {
      'name': userName,
      'message': message,
      'createdTime': DateTime.now().toUtc(),
      'imageUrl': userPhotoUrl,
      'isSeen': false,
      'isDeleted': false,
      'isRequest': isRequest,
      'type': type,
      'userId': userId
    };
  }

  String get createdSince {
    try {
      if (time == null) return 'just now';

      var differance = DateTime.now().toUtc().difference(time!);
      var years = (differance.inDays ~/ 365).toInt();
      if (years > 1) return '$years years ago';

      var months = (differance.inDays ~/ 30).toInt();
      if (months > 1) return '$months months ago';

      var weeks = (differance.inDays ~/ 7).toInt();
      if (weeks > 1) return '$weeks weeks ago';

      var days = (differance.inDays).toInt();
      if (days > 1) return '$days days ago';

      var hours = (differance.inHours).toInt();
      if (hours > 1) return '$hours hours ago';

      var minutes = (differance.inMinutes).toInt();
      if (minutes > 1) return '$minutes minutes ago';
    } catch (err) {}
    return 'Just now';
  }
}
